==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/lambda_alias/LambdaAliasRoutingConfig.java <==
package com.hashicorp.cdktf.providers.aws.lambda_alias;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.541Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.lambdaAlias.LambdaAliasRoutingConfig")
@software.amazon.jsii.Jsii.Proxy(LambdaAliasRoutingConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LambdaAliasRoutingConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_alias#additional_version_weights LambdaAlias#additional_version_weights}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.Number> getAdditionalVersionWeights() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LambdaAliasRoutingConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LambdaAliasRoutingConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<LambdaAliasRoutingConfig> {
        java.util.Map<java.lang.String, java.lang.Number> additionalVersionWeights;

        /**
         * Sets the value of {@link LambdaAliasRoutingConfig#getAdditionalVersionWeights}
         * @param additionalVersionWeights Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_alias#additional_version_weights LambdaAlias#additional_version_weights}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder additionalVersionWeights(java.util.Map<java.lang.String, ? extends java.lang.Number> additionalVersionWeights) {
            this.additionalVersionWeights = (java.util.Map<java.lang.String, java.lang.Number>)additionalVersionWeights;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LambdaAliasRoutingConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public LambdaAliasRoutingConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link LambdaAliasRoutingConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LambdaAliasRoutingConfig {
        private final java.util.Map<java.lang.String, java.lang.Number> additionalVersionWeights;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.additionalVersionWeights = software.amazon.jsii.Kernel.get(this, "additionalVersionWeights", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Number.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.additionalVersionWeights = (java.util.Map<java.lang.String, java.lang.Number>)builder.additionalVersionWeights;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Number> getAdditionalVersionWeights() {
            return this.additionalVersionWeights;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAdditionalVersionWeights() != null) {
                data.set("additionalVersionWeights", om.valueToTree(this.getAdditionalVersionWeights()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.lambdaAlias.LambdaAliasRoutingConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LambdaAliasRoutingConfig.Jsii$Proxy that = (LambdaAliasRoutingConfig.Jsii$Proxy) o;

            return this.additionalVersionWeights != null ? this.additionalVersionWeights.equals(that.additionalVersionWeights) : that.additionalVersionWeights == null;
        }

        @Override
        public final int hashCode() {
            int result = this.additionalVersionWeights != null ? this.additionalVersionWeights.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/lambda_alias/LambdaAliasRoutingConfig.java <==
package com.hashicorp.cdktf.providers.aws.lambda_alias;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.335Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.lambdaAlias.LambdaAliasRoutingConfig")
@software.amazon.jsii.Jsii.Proxy(LambdaAliasRoutingConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LambdaAliasRoutingConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/lambda_alias#additional_version_weights LambdaAlias#additional_version_weights}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.Number> getAdditionalVersionWeights() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LambdaAliasRoutingConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LambdaAliasRoutingConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<LambdaAliasRoutingConfig> {
        java.util.Map<java.lang.String, java.lang.Number> additionalVersionWeights;

        /**
         * Sets the value of {@link LambdaAliasRoutingConfig#getAdditionalVersionWeights}
         * @param additionalVersionWeights Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/lambda_alias#additional_version_weights LambdaAlias#additional_version_weights}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder additionalVersionWeights(java.util.Map<java.lang.String, ? extends java.lang.Number> additionalVersionWeights) {
            this.additionalVersionWeights = (java.util.Map<java.lang.String, java.lang.Number>)additionalVersionWeights;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LambdaAliasRoutingConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public LambdaAliasRoutingConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link LambdaAliasRoutingConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LambdaAliasRoutingConfig {
        private final java.util.Map<java.lang.String, java.lang.Number> additionalVersionWeights;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.additionalVersionWeights = software.amazon.jsii.Kernel.get(this, "additionalVersionWeights", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Number.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.additionalVersionWeights = (java.util.Map<java.lang.String, java.lang.Number>)builder.additionalVersionWeights;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Number> getAdditionalVersionWeights() {
            return this.additionalVersionWeights;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAdditionalVersionWeights() != null) {
                data.set("additionalVersionWeights", om.valueToTree(this.getAdditionalVersionWeights()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.lambdaAlias.LambdaAliasRoutingConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LambdaAliasRoutingConfig.Jsii$Proxy that = (LambdaAliasRoutingConfig.Jsii$Proxy) o;

            return this.additionalVersionWeights != null ? this.additionalVersionWeights.equals(that.additionalVersionWeights) : that.additionalVersionWeights == null;
        }

        @Override
        public final int hashCode() {
            int result = this.additionalVersionWeights != null ? this.additionalVersionWeights.hashCode() : 0;
            return result;
        }
    }
}
